@@ -1,10 +1,12 @@
 from .awsssm import AwsSsmBackend
+from .dict import DictBackend
 from .docker_secret import DockerSecretBackend
 from .dotenv import DotenvBackend
 from .env_var import EnvVarBackend
 
 __all__ = [
     'EnvVarBackend',
+    'DictBackend',
     'DotenvBackend',
     'DockerSecretBackend',
     'AwsSsmBackend',
